@@ -3,7 +3,8 @@
 
 # Configuration variables
 
-sdk_version = "0.13.0"
+sdk_version = "0.16.1"
+
 api_key = None
 client_id = None
 api_base = "https://v1.api.audio"
@@ -18,8 +19,19 @@ app_info = None
 enable_telemetry = True
 max_network_retries = 0
 
-# Set to either 'debug' or 'info', controls console logging
-log = None
-
 # API resources
 from apiaudio.api_resources import *
+
+# logging
+from apiaudio.logging import SDKLogger
+
+_logger = SDKLogger()
+_version_warning_issued = False
+
+
+def set_logger_level(level):
+    available_levels = ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]
+    level = level.upper()
+    assert level in available_levels, f"Available logging levels: {available_levels}"
+
+    _logger = SDKLogger(level=level)
