@@ -7,3 +7,5 @@ from apiaudio.api_resources.syncTTS import SyncTTS
 from apiaudio.api_resources.media import Media
 from apiaudio.api_resources.birdcache import Birdcache
 from apiaudio.api_resources.connector import Connector
+from apiaudio.api_resources.dictionary import Lexi
+from apiaudio.api_resources.orchestrator import Orchestrator
